@@ -4,7 +4,7 @@ import logging
 from six.moves.urllib.parse import urlencode
 import requests
 
-log = logging.getLogger('atlassian')
+log = logging.getLogger(__name__)
 
 
 class AtlassianRestAPI(object):
@@ -14,7 +14,7 @@ class AtlassianRestAPI(object):
     form_token_headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
                           'X-Atlassian-Token': 'no-check'}
 
-    def __init__(self, url, username, password, timeout=60, api_root='rest/api', api_version='latest', verify_ssl=True):
+    def __init__(self, url, username, password, timeout=60, api_root='rest/api', api_version='latest', verify_ssl=True, session=None):
         self.url = url
         self.username = username
         self.password = password
@@ -22,16 +22,18 @@ class AtlassianRestAPI(object):
         self.verify_ssl = verify_ssl
         self.api_root = api_root
         self.api_version = api_version
-        self._session = requests.Session()
+        if session is None:
+            self._session = requests.Session()
+        else:
+            self._session = session
         if username and password:
             self._session.auth = (username, password)
 
     def log_curl_debug(self, method, path, data=None, headers=None, level=logging.DEBUG):
         headers = headers or self.default_headers
-        message = "curl --silent -X {method} -u '{username}':'{password}' -H {headers} {data} '{url}'".format(
+        message = "curl --silent -X {method} -u '{username}':'********' -H {headers} {data} '{url}'".format(
             method=method,
             username=self.username,
-            password=self.password,
             headers=' -H '.join(["'{0}: {1}'".format(key, value) for key, value in headers.items()]),
             data='' if not data else "--data '{0}'".format(json.dumps(data)),
             url='{0}'.format(self.url_joiner(self.url, path)))
